#
# spec file for package pangomm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_ver 2.48
%define libname  lib%{name}-2_48-1

Name:           pangomm
Version:        2.56.1
Release:        1.1
Summary:        C++ interface for pango
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://gtkmm.gnome.org
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  c++_compiler
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
# m4, mm-common and perl(XML::Parser) only needed due to git-checkout
BuildRequires:  m4
BuildRequires:  mm-common
BuildRequires:  perl(XML::Parser)
#
BuildRequires:  meson >= 0.62.0
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(cairomm-1.16) >= 1.2.2
BuildRequires:  pkgconfig(giomm-2.68)
BuildRequires:  pkgconfig(glibmm-2.68)
BuildRequires:  pkgconfig(pangocairo) >= 1.54.0

%description
pangomm provides a C++ interface to the pango library.

%package -n %{libname}
Summary:        C++ interface for Pango
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{libname}
pangomm provides a C++ interface to the pango library.

%package devel
Summary:        Development files for pangomm, a C++ API for Pango
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{libname} >= %{version}
Recommends:     %{name}-doc = %{version}

%description devel
pangomm provides a C++ interface to the pango library.

%package doc
Summary:        Developer documentation for pangomm, a C++ interface for Pango
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
pangomm provides a C++ interface to the pango library.
This package contains the developer documentation.

%prep
%autosetup -p1
chmod -x NEWS

%build
%meson \
	-Dmaintainer-mode=true \
	-Dbuild-documentation=true \
	%{nil}
%meson_build

%install
%meson_install
%fdupes %{buildroot}%{_prefix}

%ldconfig_scriptlets -n %{libname}

%files -n %{libname}
%license COPYING
%doc NEWS
%{_libdir}/libpangomm-%{base_ver}.so.*

%files devel
%license COPYING.tools
%{_includedir}/pangomm-%{base_ver}/
%{_libdir}/libpangomm-%{base_ver}.so
%{_libdir}/pkgconfig/pangomm-%{base_ver}.pc
%{_libdir}/pangomm-%{base_ver}

%files doc
%doc README.md
%{_datadir}/devhelp/books/pangomm-%{base_ver}/
%{_datadir}/doc/pangomm-%{base_ver}/
# Avoid BuildRequires on devhelp
%dir %{_datadir}/devhelp
%dir %{_datadir}/devhelp/books

%changelog
* Thu Jan 16 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.56.1:
  + Add new API from pango 1.56.0
  + Regenerate docs.xml and .defs files, using files from pango
    1.56.0
  + Replace gtkmm.org by gtkmm.gnome.org
  + AttrList: Update the documentation
  + docs/reference/Doxyfile.in: Remove unsupported entries
- Update URL with new home.
* Thu Jul 25 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.54.0:
  + Color: Add parse_with_alpha().
  + Context: Add set/get_round_glyph_positions().
  + Item: Add default constructor, get_char_offset().
  + Layout: Add set/get_justify_last_line(), get_direction(),
    get_caret_pos().
  + LayoutIter: Add operator bool(), get_run_baseline().
  + LayoutLine: Add is_paragraph_start(), get_resolved_direction(),
    get_height().
  + TabArray: Add TabArray(const Glib::ustring& text) constructor,
    operator bool(), set_positions_in_pixels(), to_string(),
    set/get_decimal_point(), sort().
  + Documentation:
  - Language::get_scripts(): Improve documentation.
  - Don't link to removed parts of library.gnome.org.
  + Build:
  - Require pango >= 1.54.0.
  - Meson build: Require meson >= 0.62.0.
  - Use Meson's pkgconfig module instead of using the *.pc.in
    templates.
- Drop pangomm-docs-without-timestamp.patch, fixed upstream.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.52.0:
  + FontFamily: Add property_item_type(), property_n_items(),
    property_name(), property_is_monospace(),
    property_is_variable().
  + FontMap: Add reload_font(), property_item_type(),
    property_n_items().
* Mon Jan 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.50.2:
  + Fontset: Use callback functions with C linkage.
  + Coverage: Don't use deprecated pango_coverage_ref/unref().
  + Documentation:
  - Doxyfile.in: Don't hide undocumented classes.
  - README.win32: Convert to MarkDown and rename to
    README.win32.md.
  - Make dependencies clearer.
  - Remove AUTHORS, HACKING, README.SUN; add general info to
    README.md.
  + Meson build:
  - Detect if we build from a git subtree.
  - Don't copy files with configure_file().
  - Fix the evaluation of is_git_build on Windows.
  - Don't fail if warning_level=everything.
* Wed Sep 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.50.1:
  + Context::get_font_map(): Fix reference count.
  + Build:
  - Require Meson >= 0.55.0
  - Meson build:
    . Specify 'check' option in run_command(). Will be necessary
    with future versions of Meson.
    . Check if Perl is required for building documentation.
    . Avoid unnecessary configuration warnings.
    . Re-organize warning-related compiler flags for MSVC
- Package -docs as noarch.
- Move pangomm-doc Recommends from main package to -devel
  sub-package.
- Use ldconfig_scriptlets for post(un) handling.
* Wed Feb  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.50.0:
  * CI: Comment out 'meson test'
  * Attribute: Add some create_attr_*() methods
  * AttrList: Add to_string() and from_string()
  * Regenerate docs.xml and .defs files, using files from pango
    1.50.0
  * build: Support Visual Studio 2022 builds
  * Add FontMap::get_family()
  * Add the CairoFontMapImpl class
  * CI: Switching to debian:testing
  * AttrList: Add get_attributes(), update(), equal()
  * docs/reference/Doxyfile.in: Remove obsolete entry
  * CI: Add .gitlab-ci.yml
  * Don't include individual pango headers, part 2
  * Don't include individual pango headers
  * Use pango from the main branch
  * 2.49.1
  * Add dependencies to Doxygen tag files in subprojects
  * Fix build as subproject without building documentation
  * Visual Studio builds: Clean up build files
  * Subprojects can use meson.add_dist_script() if meson.version()
    >= 0.58.0
  * Meson build: No implicit_include_directories
  * Meson build: No implicit_include_directories
  * Meson build: Make it possible to use pangomm as a subproject
  * pangommconfig.h.*: Don't dllimport on MinGW
  * Meson build: Use relative paths to untracked/
  * GlyphItem: Make most methods public
  * Layout, LayoutIter: Add get_const_line() and get_const_lines()
- Drop baselibs.conf, not needed nor used for this branch.
* Sun Dec  5 2021 bjorn.lie@gmail.com
- Update to version 2.48.2:
  * NMake Makefiles: Correct VS2019 toolset number
  * build: Support Visual Studio 2022 builds
  * Don't include individual pango headers, part 2
  * Don't include individual pango headers
  * Use pango from the main branch
- Switch to using a gitcheckout via source service. Pass
  maintainer-mode=true to meson and add m4, mm-common and
  perl(XML::Parser) BuildRequires, as this is needed with a
  git-checkout.
* Tue Sep 28 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.1:
  + GlyphItem: Fix a memory leak in split()
  + Layout: Speed up get_log_attrs()
  + Build:
  - Meson build: Use relative paths to untracked/
  - pangommconfig.h.*: Don't dllimport on MinGW
  - Meson build: Make it possible to use pangomm as a subproject
  - Meson build: No implicit_include_directories
- Add pangomm-docs-without-timestamp.patch: Do not add timestamp to
  generated doc files.
* Sat Dec 19 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.0:
  + FontFamily, FontMap: Implement the Gio::ListModel interface
    CairoFontMap: Add get_default()
  + Attribute: Add Overline and ShowFlags enums and some create*()
    methods Renderer: Add vfuncs
  + Font, FontFace, FontFamily, FontMetrics: Add new methods
  + LayoutRun: Rename to GlyphItem
  + LayoutIter: Fix get_run() and get_line()
  + GlyphString, Item: Wrap pango_shape_with_flags()
  + Layout: Add set/get_line_spacing()
  + Build:
  - Depend on giomm (not just glibmm)
  - Use __declspec(dllexport) when building with Visual Studio
  - Meson build: Avoid some recompilations
  - Meson build: Better error message if trying to build with
    maintainer-mode=false when true is necessary
  - Meson build: Set default value of the 'warnings' option to
    'min'
  - Improve NMake support
  - Improve Visual Studio support
  - docs/reference/: Update for Doxygen >= 1.8.16
  - Meson build: Fix versioning on macOS
  - Change the ABI to pangomm-2.48
- Add meson BuildRequires and macros following upstreams port.
- Bump base_ver and libname (and in baselibs.conf) following
  upstream changes.
- Add doxygen, graphviz and xsltproc BuildRequires, needed to build
  documentation now.
- Replace pkgconfig(glibmm-2.66) with pkgconfig(giomm-2.68) and
  pkgconfig(glibmm-2.68) BuildRequires following upstream changes.
- Drop libtool and mm-common BuildRequires, no longer needed.
* Sun Mar 22 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.43.2:
  + Coverage: Remove max(), to_bytes() and one create()
  + Layout::get_lines(): Fix ownership of the GSList
  + Remove deprecated API:
  - AttrList: non-const operator bool()
  - CairoFontMap: create_context()
  - Color: non-const operator bool()
  - Layout: get_iter(LayoutIter& iter)
  - LayoutIter: assign_gobj()
  + pango/src/color.hg: Fix call to _CLASS_BOXEDTYPE_STATIC
  + Build:
  - Use glibmm-2.66 instead of glibmm-2.60
  - tools/gen_scripts: Update for non-source-dir builds
  - Add support for building pangomm with Meson
  - meson.build: Check if .git is a directory or file
  - NMake Makefiles: Allow builds from a GIT checkout
  - Visual Studio: Drop gendef.exe, use __declspec(dllexport)
  - The fixed call to _CLASS_BOXEDTYPE_STATIC in color.hg is
    necessary in order to use glibmm 2.65.1 or later, combined
    with maintainer-mode in pangomm.
- Drop upstream fixed patches:
  + pangomm-use-glibmm-266.patch
  + pangomm-use-glibmm-264.patch
  + pangomm-use-glibmm-262.patch
* Sat Mar 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add pangomm-use-glibmm-266.patch: Forward port to use libmm-2.66.
- Replace pkgconfig(glibmm-2.64) BuildRequires with
  pkgconfig(glibmm-2.66).
* Thu Feb 20 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add pangomm-use-glibmm-264.patch: Forward port to use libmm-2.64.
- Replace pkgconfig(glibmm-2.62) BuildRequires with
  pkgconfig(glibmm-2.64).
* Mon Sep  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add pangomm-use-glibmm-262.patch: Forward port to use
  glibmm-2.62. Following this, add libtool and mm-common
  BuildRequires and pass autogen.sh, as patch touches buildsystem.
- Replace pkgconfig(glibmm-2.60) with pkgconfig(glibmm-2.62) and
  gcc-c++ with the generic c++_compiler BuildRequires.
- Modernize spec.
* Mon Dec  3 2018 bjorn.lie@gmail.com
- Update to version 2.43.1:
  + Attribute: Add several create_attr_*() methods.
  + FontDescription: Add set/get_variations().
  + Build:
  - Require C++17.
  - Replace the Visual Studio project files with MSVC NMake
    project files.
  - Use glibmm-2.60 instead of glibmm-2.56.
  - Require pango >= 1.41.0 because of
    FontDescription::set/get_variations().
  - Change the ABI to pangomm-2.44.
- Bump soname following upstream changes.
- Replace pkgconfig(glibmm-2.58) with pkgconfig(glibmm-2.60)
  BuildRequires.
- Drop pangomm-glibmm-fix.patch: Fixed upstream. Following this,
  also drop libtool and mm-common BuildRequires and autogen.sh
  call, no longer needed.
* Tue Apr 17 2018 dimstar@opensuse.org
- Export CXXFLAGS="-std=c++17" until upstream catches up: required,
  as libsigc++-3.0 moved to C++17.
* Tue Apr  3 2018 bjorn.lie@gmail.com
- Add pangomm-glibmm-fix.patch: Fix build with new glibmm,
  following replace pkgconfig(glibmm-2.56) with
  pkgconfig(glibmm-2.58) BuildRequires, and add libtool and
  mm-common BuildRequires and pass autogen.sh as the patch touches
  buildsystem.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Feb 24 2018 luc14n0@linuxmail.org
- Update to version 2.41.5:
  + No visible changes.
- Update '+' in GPL/LGPL License tags to '-or-later', add GPL
  version 3 and change LGPL version to 2.1 in the preamble's
  License tag. And add GPL/LGPL License tags to all subpackages to
  comply with the copyrights.
- Drop unneeded standard BuildRoot tag declaration: RPM already
  handles this itself.
- Point fdupes to the data directory under the build root instead
  of the build root directly, which is a practice that must be
  avoided.
- Recommend the documentation subpackage.
* Sat Sep  9 2017 jengelh@inai.de
- Update package summaries.
  Avoid running fdupes across hardlink boundaries.
* Fri Aug 25 2017 zaitor@opensuse.org
- Update to version 2.41.4:
  + Build: Use glibmm-2.56 instead of glibmm-2.54. We have changed
    the ABI name in glibmm.
  + Build: Fontset: Remove GLIBMM_EXCEPTIONS_ENABLED.
  + AttrString: Let _MEMBER_GET convert from const char*
    (bgo#783360).
  + Weight enum: Make this implicitly convertible to int
    (bgo#86864).
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 2.41.3:
  + Use C++11 enum classes instead of old-style enums, and put many
    enums inside relevant class declarations:
    . Coverage: Change CoverageLevel to Coverage::Level.
    . Renderer: Change RendererPart to Renderer::Part.
  + Build: Windows: Visual Studio builds: Update glibmm ABI
    version.
- Changes from version 2.41.2:
  + Build: Use glibmm-2.54 instead of glibmm-2.52.
  + Visual Studio: Require Visual Studio 2017.
  + Replace uses of Glib::ArrayHandle<>, Glib::ListHandle, and
    Glib::SListHandle in the API with std::vector.
- Replace pkgconfig(glibmm-2.52) with pkgconfig(glibmm-2.54)
  BuildRequires following upstream changes.
* Mon Dec  5 2016 jengelh@inai.de
- Rectify RPM groups and replace old macros.
* Fri Dec  2 2016 dimstar@opensuse.org
- Update to version 2.41.1:
  + Require C++14.
  + Use glibmm-2.52 instead of glibmm-2.4.
  + Use cairomm-1.16 instad of cairomm-1.0.
- Updated BuildRequires, following upstreams changes:
  + Remove: pkgconfig(glibmm-2.4), pkgconfig(cairomm-1.0).
  + Add: pkgconfig(glibmm-2.52), pkgconfig(cairomm-1.16).
- Change so_ver to 2.42-1, resulting in the library package to be
  renamed from libpangomm-1_4-1 to libpangomm=2_42-1 (also adjust
  baselibs.conf).
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 2.40.1:
  + C++11: Make all operator bool()s explicit.
  + Build: Fix silent builds (bgo#768797).
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Mar 29 2016 zaitor@opensuse.org
- Update to version 2.40.0:
  + No major changes compared to 2.39.1.
* Mon Nov 30 2015 zaitor@opensuse.org
- Update to version 2.39.1:
  + Renderer: Added get/set_alpha().
  + Attribute: Added create_attr_background_alpha() and
    create_attr_foreground_alpha().
  + Reduce the cairomm dependency back to 1.2.2 (bgo#755460).
* Wed Sep 30 2015 zaitor@opensuse.org
- Update to version 2.38.1:
  + Regenerate with the latest glibmm.
- Changes from version 2.38.0:
  + MSVC build fixes.
* Fri Sep  4 2015 zaitor@opensuse.org
- Update to version 2.37.2:
  + Rebuilt with latest glibmm, whose gmmproc generates C++ move
    operations.
  + C++11: Mark all _CLASS_OPAQUE_REFCOUNTED classes as final.
* Sat Jul 18 2015 zaitor@opensuse.org
- Update to version 2.37.1:
  + Use (and require) C++11.
  + Attribute: fix operator!= (bgo#751531).
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 2.36.0:
  + No changes compared to 2.35.1.
* Wed Feb  4 2015 dimstar@opensuse.org
- Update to version 2.35.1:
  + Context: Add get_serial().
  + FontMap: Add get_serial().
  + Layout: Add get_character_count() and get_serial().
  + Documentatoin: Update appearance to match recent glibmm and
    gtkmm.
  + Win32 MSVC 2008/2010 Build: Many updates and corrections.
* Mon Apr 29 2013 dimstar@opensuse.org
- Update to version 2.34.0:
  + Remove the use of g_type_init() because it has been deprecated.
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 2.28.4:
  + Add #includes needed with the latest glibmm.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 2.28.3:
  + Build
  - Ship convert_pangomm.m4 in tarballs (bgo#657817).
  - Don't use obsolete macros.
* Thu Jul  7 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 2.28.2:
  + bgo#645669: Install the m4 files even without
  - -enable-maintainer-mode, as with other modules.
- Use source services: download_url and set_version.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.28.1:
  + Avoid a tarball dependency on mm-common.
- Changes from version 2.28.0:
  + regenerated tarball due to changes in an m4 macro in mm-common.
* Wed Feb 23 2011 adam@mizerski.pl
- Update to version 2.27.1:
  + LayoutIter: This now has a copy constructor.
  + Layout::get_iter(): There is now a version of this method that
    returns a LayoutIter. The version with the output parameter is
    now deprecated.
- Remove libsigc++2-devel and update-desktop-files BuildRequires.
- Change BuildRequires to pkgconfig() ones:
  + old ones: cairomm-devel, glibmm2-devel, pango-devel.
  + pkgconfig() ones: cairomm-1.0, glibmm-2.4, pangocairo.
- Remove explicit Requires for glibmm2-devel, cairomm-devel,
  atk-devel and pango-devel in devel subpackage: they will
  automatically be added the pkgconfig() way.
- Remove Requires for devel subpackage in doc subpackage: it's not
  really needed.
- Pass --disable-static to configure.
* Thu Dec  9 2010 vuntz@opensuse.org
- Update to version 2.26.3:
  + Build/Installer: Added support for MSVC 2010 and 64 bit.
* Thu Jun 10 2010 wittemar@googlemail.com
- build 32bit-package
* Thu May  6 2010 dimstar@opensuse.org
- Update to version 2.26.2:
  + Documentation: Added main page text at index.html.
- Changes from version +2.26.1:
  + Minor documentation improvements.
* Mon Sep 28 2009 vuntz@opensuse.org
- Update to version 2.26.0:
  + Minor documentation build fixes.
* Fri Aug 28 2009 vuntz@novell.com
- Update to version 2.25.1.3:
  + Change public documentation location to library.gnome.org in
    the pkg-config files as well.
- Changes from version 2.25.1.2:
  + Change public documentation location to library.gnome.org.
- Changes from version 2.25.1.1:
  + Reenable the per-class hierarchy graphs in the reference
    documentation.
  + Drop the custom HTML header and footer, and use the shared
    doxygen.css file from mm-common.
* Wed Aug 26 2009 dimstar@opensuse.org
- Update to version 2.25.1:
  + Reworked the build system, using mm-common.
* Thu Mar 26 2009 vuntz@novell.com
- Remove BuildRequires on devhelp: it's only needed for directory
  ownership, and we can own the directories anyway.
* Tue Mar 10 2009 vuntz@novell.com
- Update to version 2.24.0:
  + Layout: Added show_in_cairo_context(). bgo#560232.
  + Build: Allow pangomm to build outside the source tree.
    bgo#570322
  + License Header consistency.
* Mon Dec  8 2008 mboman@suse.de
- Update to version 2.14.1:
  + Windows build: Use the new DLL naming convention, like boost.
  + Corrected the index page for DevHelp (bgo#559896)
* Wed Oct 22 2008 maw@suse.de
- Make debug packages require a specific %%{version}-%%{release}.
* Fri Oct  3 2008 mboman@suse.de
- Update to version 2.14.0:
  + Language: Added get_scripts().
  + README and COPYING fixes.
  + Fixed the Windows build with Visual Studio Express
* Thu Sep 18 2008 maw@suse.de
- Update to version 2.13.8:
  + Context: Added set_font_map() because the C function is now
    public (non backend-only) API
  + LayoutRun/GlyphItem: Added split() and letter()
  + Renderer: Added draw_glyph_item()
  + CairoFontMap:: Added set_default().
* Thu Sep 18 2008 maw@suse.de
- Initial import of version 2.13.7.
